@@ -5,17 +5,14 @@ import json
 import logging
 import pandas
 import pyfygentlescrap as pfgs
-import requests
-import urllib
-
 from json.decoder import JSONDecodeError
-from requests.exceptions import ConnectTimeout
-from requests.exceptions import ConnectionError
+from pyfygentlescrap import InvalidResponseWarning, WrongTypeWarning
+from pyfygentlescrap.yahoo.yahoo_shared import _get_http_response
 
 logger = logging.getLogger(__name__)
 
 
-def yahoo_ticker(ticker="", yahoo_session=None):
+def yahoo_ticker(ticker, session=None):
     """
     Download live or delayed data for a single ticker, then returns
     a `DataFrame` object.
@@ -26,11 +23,11 @@ def yahoo_ticker(ticker="", yahoo_session=None):
 
     Parameters:
         ticker (str): Yahoo ticker to download
-        yahoo_session (pfgs.yahoo_session, optional):  Existing yahoo session.
+        session (pfgs.yahoo_session, optional):  Existing yahoo session.
             If no yahoo_session is provided, the function will open one for the
             duration of the function execution. The latter session will be lost
             when `yahoo_historical_data` function exit. For large data
-            scrapping, the use of `yahoo_session` is higly recommended to reuse
+            scrapping, the use of ``session`` is higly recommended to reuse
             existing cookies and crumb values. It will also reduce the cpu
             usage.
 
@@ -73,24 +70,16 @@ def yahoo_ticker(ticker="", yahoo_session=None):
 
     """
     if not isinstance(ticker, str):
-        logger.warning(
-            f"Parameter ticker={ticker}, type={type(ticker)} must "
-            f"be a <str> object. A void DataFrame will be return."
-        )
+        WrongTypeWarning.warn(ticker, str, "A void DataFrame will be return.")
         return pandas.DataFrame()
     # Get crumb value + headers:
-    if yahoo_session is None:
-        try:
-            yahoo_session = pfgs.yahoo_session()
-        except (ConnectTimeout, ConnectionError):
-            return pandas.DataFrame()
-    crumb = yahoo_session.crumb
-    cookies = yahoo_session.cookies
+    if session is None:
+        session = pfgs.yahoo_session()
 
     # Building url requests:
     params = {
         "formatted": True,
-        "crumb": crumb,
+        "crumb": session.crumb,
         "lang": "en-US",
         "region": "US",
         "symbols": ticker,
@@ -102,45 +91,25 @@ def yahoo_ticker(ticker="", yahoo_session=None):
         "corsDomain": "finance.yahoo.com",
     }
 
-    # Sending the GET request, first on query1 server, if fail, on query2:
-    url_path = "https://query1.finance.yahoo.com/v7/finance/quote"
-    url = f"{url_path}?{urllib.parse.urlencode(params)}"
-    logger.debug(f"Sending requests GET {url}")
-    try:
-        response = requests.get(url, cookies=cookies)
-    except (ConnectTimeout, ConnectionError):
-        logger.warning("Internet connection seems to be down.")
-        return pandas.DataFrame()
-    if response.status_code != 200:
-        logger.debug(
-            "Server query1 response was not 200. "
-            "Sending the same requests to server https://query2"
-        )
-        url_path = "https://query2.finance.yahoo.com/v7/finance/quote"
-        url = f"{url_path}?{urllib.parse.urlencode(params)}"
-        response = requests.get(url, cookies=cookies)
-        if response.status_code != 200:
-            logger.debug(
-                f"Request {url} did not return a valid response. "
-                f"A void DataFrame will be return."
-            )
-            return pandas.DataFrame()
+    # POST request on both query servers:
+    response = _get_http_response(
+        "GET",
+        path="v7/finance/quote",
+        params=params,
+        headers=session.headers,
+    )
 
     # Parsing results:
     try:
         _json = json.loads(response.text)
-    except JSONDecodeError:
-        logger.debug(
-            "Request did not return a valid response. "
-            "A void DataFrame will be return."
-        )
+    except (JSONDecodeError, AttributeError):
+        InvalidResponseWarning.warn("Request", "A void DataFrame will be return.")
         return pandas.DataFrame()
     try:
         _json = _json["quoteResponse"]["result"][0]
-    except IndexError:
-        logger.debug(
-            f"Ticker {ticker} did not return a valid response. "
-            f"A void DataFrame will be return."
+    except (IndexError, KeyError):
+        InvalidResponseWarning.warn(
+            "Ticker '{ticker}'", "A void DataFrame will be return."
         )
         return pandas.DataFrame()
 
